pub struct Config {
pub app_theme: AppTheme,
pub dialog: DialogConfig,
pub desktop: DesktopConfig,
pub context_actions: Vec<ContextActionPreset>,
pub thumb_cfg: ThumbCfg,
pub favorites: Vec<Favorite>,
pub show_details: bool,
pub show_recents: bool,
pub tab: TabConfig,
pub type_to_search: TypeToSearch,
pub tb_config: TBConfig,
}Fields
app_theme: AppThemedialog: DialogConfigdesktop: DesktopConfigcontext_actions: Vec<ContextActionPreset>thumb_cfg: ThumbCfgfavorites: Vec<Favorite>show_details: boolshow_recents: booltab: TabConfigtype_to_search: TypeToSearchtb_config: TBConfigImplementations
Sourceimpl Config
impl Config
Sourcepub fn set_app_theme(
&mut self,
config: &Config,
value: AppTheme,
) -> Result<bool, Error>
pub fn set_app_theme( &mut self, config: &Config, value: AppTheme, ) -> Result<bool, Error>
Sets Config::app_theme and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_dialog(
&mut self,
config: &Config,
value: DialogConfig,
) -> Result<bool, Error>
pub fn set_dialog( &mut self, config: &Config, value: DialogConfig, ) -> Result<bool, Error>
Sets Config::dialog and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_desktop(
&mut self,
config: &Config,
value: DesktopConfig,
) -> Result<bool, Error>
pub fn set_desktop( &mut self, config: &Config, value: DesktopConfig, ) -> Result<bool, Error>
Sets Config::desktop and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_context_actions(
&mut self,
config: &Config,
value: Vec<ContextActionPreset>,
) -> Result<bool, Error>
pub fn set_context_actions( &mut self, config: &Config, value: Vec<ContextActionPreset>, ) -> Result<bool, Error>
Sets Config::context_actions and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_thumb_cfg(
&mut self,
config: &Config,
value: ThumbCfg,
) -> Result<bool, Error>
pub fn set_thumb_cfg( &mut self, config: &Config, value: ThumbCfg, ) -> Result<bool, Error>
Sets Config::thumb_cfg and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_favorites(
&mut self,
config: &Config,
value: Vec<Favorite>,
) -> Result<bool, Error>
pub fn set_favorites( &mut self, config: &Config, value: Vec<Favorite>, ) -> Result<bool, Error>
Sets Config::favorites and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_details(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_details( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets Config::show_details and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_recents(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_recents( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets Config::show_recents and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_tab(
&mut self,
config: &Config,
value: TabConfig,
) -> Result<bool, Error>
pub fn set_tab( &mut self, config: &Config, value: TabConfig, ) -> Result<bool, Error>
Sets Config::tab and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_type_to_search(
&mut self,
config: &Config,
value: TypeToSearch,
) -> Result<bool, Error>
pub fn set_type_to_search( &mut self, config: &Config, value: TypeToSearch, ) -> Result<bool, Error>
Sets Config::type_to_search and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_tb_config(
&mut self,
config: &Config,
value: TBConfig,
) -> Result<bool, Error>
pub fn set_tb_config( &mut self, config: &Config, value: TBConfig, ) -> Result<bool, Error>
Sets Config::tb_config and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk