pub struct DesktopConfig {
pub grid_spacing: NonZeroU16,
pub icon_size: NonZeroU16,
pub show_content: bool,
pub show_mounted_drives: bool,
pub show_connected_drives: bool,
pub show_trash: bool,
}Fields
grid_spacing: NonZeroU16icon_size: NonZeroU16show_content: boolshow_mounted_drives: boolshow_connected_drives: boolshow_trash: boolImplementations
Sourceimpl DesktopConfig
impl DesktopConfig
Sourcepub fn set_grid_spacing(
&mut self,
config: &Config,
value: NonZeroU16,
) -> Result<bool, Error>
pub fn set_grid_spacing( &mut self, config: &Config, value: NonZeroU16, ) -> Result<bool, Error>
Sets DesktopConfig::grid_spacing and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_icon_size(
&mut self,
config: &Config,
value: NonZeroU16,
) -> Result<bool, Error>
pub fn set_icon_size( &mut self, config: &Config, value: NonZeroU16, ) -> Result<bool, Error>
Sets DesktopConfig::icon_size and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_content(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_content( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets DesktopConfig::show_content and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_mounted_drives(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_mounted_drives( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets DesktopConfig::show_mounted_drives and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_connected_drives(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_connected_drives( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets DesktopConfig::show_connected_drives and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_trash(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_trash( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets DesktopConfig::show_trash and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourceimpl DesktopConfig
impl DesktopConfig
pub fn grid_spacing_for(&self, space: u16) -> u16