pub struct DialogConfig {
pub folders_first: bool,
pub icon_sizes: IconSizes,
pub show_details: bool,
pub show_hidden: bool,
pub view: View,
pub show_susceptible: bool,
}Fields
folders_first: boolShow folders before files
icon_sizes: IconSizesIcon zoom
show_details: boolShow details sidebar
Show hidden files and folders
view: ViewSelected view, grid or list
show_susceptible: boolShow susceptible samples
Implementations
Sourceimpl DialogConfig
impl DialogConfig
Sourcepub fn set_folders_first(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_folders_first( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets DialogConfig::folders_first and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_icon_sizes(
&mut self,
config: &Config,
value: IconSizes,
) -> Result<bool, Error>
pub fn set_icon_sizes( &mut self, config: &Config, value: IconSizes, ) -> Result<bool, Error>
Sets DialogConfig::icon_sizes and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_details(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_details( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets DialogConfig::show_details and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets DialogConfig::show_hidden and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_view(&mut self, config: &Config, value: View) -> Result<bool, Error>
pub fn set_view(&mut self, config: &Config, value: View) -> Result<bool, Error>
Sets DialogConfig::view and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_susceptible(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_susceptible( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets DialogConfig::show_susceptible and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk