pub struct TBConfig {
pub script_path: String,
pub out_dir: String,
pub docx_template_path: String,
pub pair1_suffix: String,
pub pair2_suffix: String,
pub ab1_scan_path: String,
pub ab1_cache_path: String,
pub ab1_out_dir_csv: String,
pub ab1_out_dir_pdf: String,
pub ntfy_topic: String,
pub report_max_age_days: u32,
}Fields
script_path: Stringout_dir: Stringdocx_template_path: Stringpair1_suffix: Stringpair2_suffix: Stringab1_scan_path: Stringab1_cache_path: Stringab1_out_dir_csv: Stringab1_out_dir_pdf: Stringntfy_topic: Stringreport_max_age_days: u32Implementations
Sourceimpl TBConfig
impl TBConfig
Sourcepub fn set_script_path(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_script_path( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::script_path and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_out_dir(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_out_dir( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::out_dir and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_docx_template_path(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_docx_template_path( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::docx_template_path and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_pair1_suffix(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_pair1_suffix( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::pair1_suffix and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_pair2_suffix(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_pair2_suffix( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::pair2_suffix and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_ab1_scan_path(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_ab1_scan_path( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::ab1_scan_path and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_ab1_cache_path(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_ab1_cache_path( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::ab1_cache_path and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_ab1_out_dir_csv(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_ab1_out_dir_csv( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::ab1_out_dir_csv and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_ab1_out_dir_pdf(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_ab1_out_dir_pdf( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::ab1_out_dir_pdf and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_ntfy_topic(
&mut self,
config: &Config,
value: String,
) -> Result<bool, Error>
pub fn set_ntfy_topic( &mut self, config: &Config, value: String, ) -> Result<bool, Error>
Sets TBConfig::ntfy_topic and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_report_max_age_days(
&mut self,
config: &Config,
value: u32,
) -> Result<bool, Error>
pub fn set_report_max_age_days( &mut self, config: &Config, value: u32, ) -> Result<bool, Error>
Sets TBConfig::report_max_age_days and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk