TabConfig

Struct TabConfig 

pub struct TabConfig {
    pub folders_first: bool,
    pub icon_sizes: IconSizes,
    pub military_time: bool,
    pub show_hidden: bool,
    pub single_click: bool,
    pub view: View,
    pub show_as_samples: bool,
    pub show_susceptible: bool,
}
Global and local crate::tab::Tab config.

TabConfig contains options that are passed to each instance of crate::tab::Tab. These options are set globally through the main config, but each tab may change options locally. Local changes aren’t saved to the main config.

Fields

folders_first: bool

Show folders before files

icon_sizes: IconSizes

Icon zoom

military_time: bool

24 hour clock; this is neither serialized nor deserialized because we use the user’s global preference rather than save it

show_hidden: bool

Show hidden files and folders

single_click: bool

Single click to open

view: View

Selected view, grid or list

show_as_samples: bool

Show samples instead of files

show_susceptible: bool

Show susceptible samples

Implementations

Source

impl TabConfig

pub fn set_folders_first( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>

Sets TabConfig::folders_first and writes to [cosmic_config::Config] if changed

Returns Ok(true) when the field’s value has changed and was written to disk

pub fn set_icon_sizes( &mut self, config: &Config, value: IconSizes, ) -> Result<bool, Error>

Sets TabConfig::icon_sizes and writes to [cosmic_config::Config] if changed

Returns Ok(true) when the field’s value has changed and was written to disk

pub fn set_military_time( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>

Sets TabConfig::military_time and writes to [cosmic_config::Config] if changed

Returns Ok(true) when the field’s value has changed and was written to disk

pub fn set_show_hidden( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>

Sets TabConfig::show_hidden and writes to [cosmic_config::Config] if changed

Returns Ok(true) when the field’s value has changed and was written to disk

pub fn set_single_click( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>

Sets TabConfig::single_click and writes to [cosmic_config::Config] if changed

Returns Ok(true) when the field’s value has changed and was written to disk

pub fn set_view(&mut self, config: &Config, value: View) -> Result<bool, Error>

Sets TabConfig::view and writes to [cosmic_config::Config] if changed

Returns Ok(true) when the field’s value has changed and was written to disk

pub fn set_show_as_samples( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>

Sets TabConfig::show_as_samples and writes to [cosmic_config::Config] if changed

Returns Ok(true) when the field’s value has changed and was written to disk

pub fn set_show_susceptible( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>

Sets TabConfig::show_susceptible and writes to [cosmic_config::Config] if changed

Returns Ok(true) when the field’s value has changed and was written to disk