pub struct TabConfig {
pub folders_first: bool,
pub icon_sizes: IconSizes,
pub military_time: bool,
pub show_hidden: bool,
pub single_click: bool,
pub view: View,
pub show_as_samples: bool,
pub show_susceptible: bool,
}Expand description
Global and local crate::tab::Tab config.
TabConfig contains options that are passed to each instance of crate::tab::Tab.
These options are set globally through the main config, but each tab may change options
locally. Local changes aren’t saved to the main config.
Fields
folders_first: boolShow folders before files
icon_sizes: IconSizesIcon zoom
military_time: bool24 hour clock; this is neither serialized nor deserialized because we use the user’s global preference rather than save it
Show hidden files and folders
single_click: boolSingle click to open
view: ViewSelected view, grid or list
show_as_samples: boolShow samples instead of files
show_susceptible: boolShow susceptible samples
Implementations
Sourceimpl TabConfig
impl TabConfig
Sourcepub fn set_folders_first(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_folders_first( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets TabConfig::folders_first and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_icon_sizes(
&mut self,
config: &Config,
value: IconSizes,
) -> Result<bool, Error>
pub fn set_icon_sizes( &mut self, config: &Config, value: IconSizes, ) -> Result<bool, Error>
Sets TabConfig::icon_sizes and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_military_time(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_military_time( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets TabConfig::military_time and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sets TabConfig::show_hidden and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_single_click(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_single_click( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets TabConfig::single_click and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_view(&mut self, config: &Config, value: View) -> Result<bool, Error>
pub fn set_view(&mut self, config: &Config, value: View) -> Result<bool, Error>
Sets TabConfig::view and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_as_samples(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_as_samples( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets TabConfig::show_as_samples and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk
Sourcepub fn set_show_susceptible(
&mut self,
config: &Config,
value: bool,
) -> Result<bool, Error>
pub fn set_show_susceptible( &mut self, config: &Config, value: bool, ) -> Result<bool, Error>
Sets TabConfig::show_susceptible and writes to [cosmic_config::Config] if changed
Returns Ok(true) when the field’s value has changed and was written to disk